@@ -121,7 +121,7 @@
                                                   
   
   ### get needed models prediction ###
-  needed_predictions <- get_needed_models(EM.output)
+  needed_predictions <- get_needed_models(EM.output, selected.models=selected.models)
   
   if (length(projection.output)){
     formal_pred <- get_predictions(projection.output, full.name=needed_predictions, as.data.frame=ifelse(projection.output@type=='array',T,F) )
@@ -145,7 +145,7 @@
   
   ef.out <- NULL
   # 2. Do the ensemble modeling
-  for( em.comp in EM.output@em.computed){
+  for( em.comp in EM.output@em.computed[which(EM.output@em.computed %in% selected.models)]){
     cat("\n\n\t> Projecting", em.comp, "...")
     model.tmp <- NULL
     BIOMOD_LoadModels(EM.output, full.name=em.comp, as='model.tmp')
@@ -164,6 +164,7 @@
         if(output.format== '.RData'){
           save(ef.tmp, file=file_name_tmp, compress=compress)
         } else{
+          ## TODO : define the raster dataformat (depends if em.cv has been computed)
           writeRaster(ef.tmp,filename=file_name_tmp, overwrite=TRUE)
         }
         saved.files <- c(saved.files, file_name_tmp)
@@ -174,19 +175,20 @@
       
   }
   
-  proj_out@models.projected <- EM.output@em.computed
+  proj_out@models.projected <- EM.output@em.computed[which(EM.output@em.computed %in% selected.models)]
   
   if(do.stack){
     if( inherits(ef.out, "Raster") ) {
-      names(ef.out) <- EM.output@em.computed
+      names(ef.out) <- proj_out@models.projected
     } else {
-      colnames(ef.out) <- EM.output@em.computed
+      colnames(ef.out) <- proj_out@models.projected
     }
     # save object
     file_name_tmp <- file.path(EM.output@sp.name,paste("proj_", proj.name, sep=""),paste("proj_", proj.name,"_",EM.output@sp.name,"_ensemble",output.format,sep=""))
     if(output.format== '.RData'){
       save(ef.out, file=file_name_tmp, compress=compress)
     } else if( inherits(ef.out, "Raster") ){
+      ## TODO : define the raster dataformat (depends if em.cv has been computed)
       writeRaster(ef.out,filename=file_name_tmp, overwrite=TRUE)
     }
     saved.files <- c(saved.files, file_name_tmp)
@@ -218,10 +220,11 @@
       if(!do.stack){
         for(i in 1:length(proj_out@proj@link)){
           file.tmp <- proj_out@proj@link[i]
-          thres.tmp <- thresholds[i]
-          writeRaster(x = BinaryTransformation(raster(file.tmp),thres.tmp),
+          thres.tmp <- thresholds[i]          
+          writeRaster(x = BinaryTransformation(raster(file.tmp, RAT=FALSE),thres.tmp),
                       filename = sub(output.format, paste("_",eval.meth,"bin", output.format, sep=""), file.tmp), 
-                      overwrite=TRUE)
+                      overwrite=TRUE,
+                      datatype = "INT1S",NAflag=-127)
         }
       } else {
         assign(x = paste("proj_",proj.name, "_", EM.output@sp.name,"_ensemble_",eval.meth,"bin", sep=""),
@@ -232,7 +235,9 @@
                file = file.path(EM.output@sp.name, paste("proj_", proj.name, sep= ""), paste("proj_",proj.name,"_", EM.output@sp.name,"_ensemble_",eval.meth,"bin", output.format ,sep="")), compress=compress)   
         } else {
           writeRaster(x=get(paste("proj_",proj.name, "_", EM.output@sp.name,"_ensemble_",eval.meth,"bin", sep="")),
-                      filename=file.path(EM.output@sp.name, paste("proj_", proj.name, sep= ""), paste("proj_",proj.name,"_", EM.output@sp.name,"_ensemble_",eval.meth,"bin", output.format ,sep="")), overwrite=TRUE)
+                      filename=file.path(EM.output@sp.name, paste("proj_", proj.name, sep= ""), paste("proj_",proj.name,"_", EM.output@sp.name,"_ensemble_",eval.meth,"bin", output.format ,sep="")), 
+                      overwrite=TRUE,
+                      datatype = "INT1S", NAflag=-127)
         }
         
         rm(list=paste("proj_",proj.name, "_", EM.output@sp.name,"_ensemble_",eval.meth,"bin", sep=""))
@@ -246,7 +251,8 @@
         for(i in 1:length(proj_out@proj@link)){
           file.tmp <- proj_out@proj@link[i]
           thres.tmp <- thresholds[i]
-          writeRaster(x = FilteringTransformation(raster(file.tmp),thres.tmp),
+          ## TODO : define the raster dataformat (depends if em.cv has been computed)
+          writeRaster(x = FilteringTransformation(raster(file.tmp, RAT=FALSE),thres.tmp),
                       filename = sub(output.format, paste("_",eval.meth,"filt", output.format, sep=""), file.tmp), 
                       overwrite=TRUE)
         }
@@ -258,6 +264,7 @@
           save(list = paste("proj_",proj.name, "_", EM.output@sp.name,"_ensemble_",eval.meth,"filt", sep=""), 
                file = file.path(EM.output@sp.name, paste("proj_", proj.name, sep= ""), paste("proj_",proj.name,"_", EM.output@sp.name,"_ensemble_",eval.meth,"filt", output.format ,sep="")), compress=compress)   
         } else {
+          ## TODO : define the raster dataformat (depends if em.cv has been computed)
           writeRaster(x=get(paste("proj_",proj.name, "_", EM.output@sp.name,"_ensemble_",eval.meth,"filt", sep="")),
                       filename=file.path(EM.output@sp.name, paste("proj_", proj.name, sep= ""), paste("proj_",proj.name,"_", EM.output@sp.name,"_ensemble_",eval.meth,"filt", output.format ,sep="")), overwrite=TRUE)
         }
@@ -268,8 +275,6 @@
   }
   
   
-  
-  
   # save object
   if(!keep.in.memory){
     proj_out <- free(proj_out)
@@ -310,7 +315,7 @@
   }
   
   # check all needed predictions are available
-  needed_pred <- get_needed_models(EM.output)
+  needed_pred <- get_needed_models(EM.output, selected.models=selected.models)  
   
   if(!is.null(projection.output)){
     if(!inherits(projection.output, "BIOMOD.projection.out")){
