@@ -108,84 +108,86 @@ get_var_range <- function(data){
 
 # Function to check new data range compatibility with calibrating data #
 check_data_range <- function(model, new_data){
-  # get calibration data caracteristics
-  expl_var_names <- model@expl_var_names
-  expl_var_type <- model@expl_var_type
-  expl_var_range <- model@expl_var_range
+  ## TODO : remettre en marche cette fonction
   
-  if(inherits(new_data, "Raster")){ ## raster data case =-=-=-=-=-=-=- #
-    # check var names compatibility
-    nd_expl_var_names <- names(new_data)
-    if(sum(!(expl_var_names %in% nd_expl_var_names) ) > 0 ){
-      stop("calibration and projections variables names mismatch")
-    }
-    # reorder the stack
-    new_data <- raster::subset(new_data,expl_var_names)
-    # check var types compatibility (factors)
-    expl_var_fact <- (expl_var_type=='factor')
-    nd_expl_var_fact <- is.factor(new_data)  
-    if(sum(! (expl_var_fact==nd_expl_var_fact))>0){
-      stop("calibration and projections variables class mismatch")
-    }
-    # check var range compatibility
-    ### remove all new factors
-    if(sum(expl_var_fact)>0){ ## there are factorial variables
-      for(fact_var_id in which(expl_var_fact)){
-        ## check if new factors occurs
-        nd_levels <- levels(raster::subset(new_data,fact_var_id))[[1]]
-        nd_levels <- as.character(nd_levels[,ncol(nd_levels)])
-        names(nd_levels) <- levels(raster::subset(new_data,fact_var_id))[[1]]$ID
-        cd_levels <- as.character(unlist(expl_var_range[[fact_var_id]]))
-        
-        ## detect new levels
-        new_levels <- nd_levels[!(nd_levels %in% cd_levels)]
-        
-        if(length(new_levels)){
-          for(n_l in new_levels){
-            # remove points where out of range factors have been detected
-            new_data[subset(new_data,fact_var_id)[]==as.numeric(names(nd_levels)[which(nd_levels==n_l)])] <- NA
-          }
-          warning(paste(nd_expl_var_names[fact_var_id]," new levels have been removed from dataset (",toString(new_levels),")",sep=""))
-        }
-      }
-    }
-    ## convert data to be sure to get RasterStack output
-#     new_data <- stack(new_data)
-  } else{ ## table data case -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- #
-    # check var names compatibility
-    nd_expl_var_names <- colnames(new_data)
-    if(sum(!(expl_var_names %in% nd_expl_var_names) ) > 0 ){
-      stop("calibration and projections variables names mismatch")
-    }
-    # reorder the stack
-    new_data <- new_data[,expl_var_names, drop=F]
-    # check var types compatibility (factors)
-    expl_var_fact <- (expl_var_type=='factor')
-    nd_expl_var_fact <- sapply(new_data,is.factor)
-
-    if(sum(! (expl_var_fact==nd_expl_var_fact))>0){
-      stop("calibration and projections variables class mismatch")
-    }
-    # check var range compatibility
-    ### remove all new factors
-    if(sum(expl_var_fact)>0){ ## there are factorial variables
-      for(fact_var_id in which(expl_var_fact)){
-        ## check if new factors occurs
-        nd_levels <- levels(new_data[,fact_var_id])
-        cd_levels <- as.character(unlist(expl_var_range[[fact_var_id]]))
-        
-        ## detect new levels
-        new_levels <- nd_levels[!(nd_levels %in% cd_levels)]
-        
-        if(length(new_levels)){
-          # remove points where out of range factors have been detected
-#           new_data <- new_data[- which(new_data[,fact_var_id] %in% new_levels),]
-          new_data[which(new_data[,fact_var_id] %in% new_levels),] <- NA
-          warning(paste(nd_expl_var_names[fact_var_id]," new levels have been removed from dataset (",toString(new_levels),")",sep=""))
-        }
-      }
-    }
-  }
+#   # get calibration data caracteristics
+#   expl_var_names <- model@expl_var_names
+#   expl_var_type <- model@expl_var_type
+#   expl_var_range <- model@expl_var_range
+#   
+#   if(inherits(new_data, "Raster")){ ## raster data case =-=-=-=-=-=-=- #
+#     # check var names compatibility
+#     nd_expl_var_names <- names(new_data)
+#     if(sum(!(expl_var_names %in% nd_expl_var_names) ) > 0 ){
+#       stop("calibration and projections variables names mismatch")
+#     }
+#     # reorder the stack
+#     new_data <- raster::subset(new_data,expl_var_names)
+#     # check var types compatibility (factors)
+#     expl_var_fact <- (expl_var_type=='factor')
+#     nd_expl_var_fact <- is.factor(new_data)  
+#     if(sum(! (expl_var_fact==nd_expl_var_fact))>0){
+#       stop("calibration and projections variables class mismatch")
+#     }
+#     # check var range compatibility
+#     ### remove all new factors
+#     if(sum(expl_var_fact)>0){ ## there are factorial variables
+#       for(fact_var_id in which(expl_var_fact)){
+#         ## check if new factors occurs
+#         nd_levels <- levels(raster::subset(new_data,fact_var_id))[[1]]
+#         nd_levels <- as.character(nd_levels[,ncol(nd_levels)])
+#         names(nd_levels) <- levels(raster::subset(new_data,fact_var_id))[[1]]$ID
+#         cd_levels <- as.character(unlist(expl_var_range[[fact_var_id]]))
+#         
+#         ## detect new levels
+#         new_levels <- nd_levels[!(nd_levels %in% cd_levels)]
+#         
+#         if(length(new_levels)){
+#           for(n_l in new_levels){
+#             # remove points where out of range factors have been detected
+#             new_data[subset(new_data,fact_var_id)[]==as.numeric(names(nd_levels)[which(nd_levels==n_l)])] <- NA
+#           }
+#           warning(paste(nd_expl_var_names[fact_var_id]," new levels have been removed from dataset (",toString(new_levels),")",sep=""))
+#         }
+#       }
+#     }
+#     ## convert data to be sure to get RasterStack output
+# #     new_data <- stack(new_data)
+#   } else{ ## table data case -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=- #
+#     # check var names compatibility
+#     nd_expl_var_names <- colnames(new_data)
+#     if(sum(!(expl_var_names %in% nd_expl_var_names) ) > 0 ){
+#       stop("calibration and projections variables names mismatch")
+#     }
+#     # reorder the stack
+#     new_data <- new_data[,expl_var_names, drop=F]
+#     # check var types compatibility (factors)
+#     expl_var_fact <- (expl_var_type=='factor')
+#     nd_expl_var_fact <- sapply(new_data,is.factor)
+# 
+#     if(sum(! (expl_var_fact==nd_expl_var_fact))>0){
+#       stop("calibration and projections variables class mismatch")
+#     }
+#     # check var range compatibility
+#     ### remove all new factors
+#     if(sum(expl_var_fact)>0){ ## there are factorial variables
+#       for(fact_var_id in which(expl_var_fact)){
+#         ## check if new factors occurs
+#         nd_levels <- levels(new_data[,fact_var_id])
+#         cd_levels <- as.character(unlist(expl_var_range[[fact_var_id]]))
+#         
+#         ## detect new levels
+#         new_levels <- nd_levels[!(nd_levels %in% cd_levels)]
+#         
+#         if(length(new_levels)){
+#           # remove points where out of range factors have been detected
+# #           new_data <- new_data[- which(new_data[,fact_var_id] %in% new_levels),]
+#           new_data[which(new_data[,fact_var_id] %in% new_levels),] <- NA
+#           warning(paste(nd_expl_var_names[fact_var_id]," new levels have been removed from dataset (",toString(new_levels),")",sep=""))
+#         }
+#       }
+#     }
+#   }
   
   return(new_data)
 }
@@ -208,10 +210,13 @@ setMethod('predict', signature(object = 'ANN_biomod2_model'),
             
             args <- list(...)
             
-#             if( ! ("package:nnet" %in% search()) ){ require(nnet,quietly=TRUE) }
-            
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+    
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.ANN_biomod2_model.RasterStack(object, newdata, ... ))
@@ -243,8 +248,12 @@ setMethod('predict', signature(object = 'ANN_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
 
   return(proj)
@@ -258,6 +267,8 @@ setMethod('predict', signature(object = 'ANN_biomod2_model'),
   if (is.null(on_0_1000)) on_0_1000 <- FALSE
   if (is.null(omit.na)) omit.na <- FALSE
   
+  
+  
   ## check if na occurs in newdata cause they are not well supported
   if(omit.na){
     not_na_rows <- apply(newdata, 1, function(x){sum(is.na(x))==0})
@@ -307,10 +318,13 @@ setMethod('predict', signature(object = 'CTA_biomod2_model'),
             
             args <- list(...)
             
-#             if( ! ("package:rpart" %in% search()) ){ require(rpart,quietly=TRUE) }
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.CTA_biomod2_model.RasterStack(object, newdata, ... ))
@@ -342,10 +356,15 @@ setMethod('predict', signature(object = 'CTA_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
+  
   return(proj)
 }
 
@@ -405,10 +424,13 @@ setMethod('predict', signature(object = 'FDA_biomod2_model'),
             
             args <- list(...)
             
-#             if( ! ("package:mda" %in% search()) ){ require(mda,quietly=TRUE) }
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.FDA_biomod2_model.RasterStack(object, newdata, ... ))
@@ -439,10 +461,15 @@ setMethod('predict', signature(object = 'FDA_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
+  
   return(proj)
 }
 
@@ -505,6 +532,11 @@ setMethod('predict', signature(object = 'GAM_biomod2_model'),
           function(object, newdata, ...){
             
             args <- list(...)
+            
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+            
+            
             if(object@model_subclass %in% c("GAM_mgcv","BAM_mgcv")){
               if( ("package:gam" %in% search()) ){ detach("package:gam", unload=TRUE)}
               if( ! ("package:mgcv" %in% search()) ){ require(mgcv,quietly=TRUE) }
@@ -518,7 +550,9 @@ setMethod('predict', signature(object = 'GAM_biomod2_model'),
             }
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.GAM_biomod2_model.RasterStack(object, newdata, ... ))
@@ -549,10 +583,15 @@ setMethod('predict', signature(object = 'GAM_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
+  
   return(proj)
 }
 
@@ -612,10 +651,13 @@ setMethod('predict', signature(object = 'GBM_biomod2_model'),
             
             args <- list(...)
             
-#             if( ! ("package:gbm" %in% search()) ){ require(gbm,quietly=TRUE) }
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.GBM_biomod2_model.RasterStack(object, newdata, ... ))
@@ -647,10 +689,15 @@ setMethod('predict', signature(object = 'GBM_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
+  
   return(proj)
 }
 
@@ -709,10 +756,13 @@ setMethod('predict', signature(object = 'GLM_biomod2_model'),
             
             args <- list(...)
             
-#             if( ! ("package:stats" %in% search()) ){ require(stats,quietly=TRUE) }
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.GLM_biomod2_model.RasterStack(object, newdata, ... ))
@@ -745,10 +795,15 @@ setMethod('predict', signature(object = 'GLM_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
+  
   return(proj)
 }
 
@@ -807,10 +862,13 @@ setMethod('predict', signature(object = 'MARS_biomod2_model'),
             
             args <- list(...)
             
-#             if( ! ("package:mda" %in% search()) ){ require(mda,quietly=TRUE) }
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.MARS_biomod2_model.RasterStack(object, newdata, ... ))
@@ -841,10 +899,15 @@ setMethod('predict', signature(object = 'MARS_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
+  
   return(proj)
 }
 
@@ -900,11 +963,14 @@ setClass('MAXENT_biomod2_model',
 
 setMethod('predict', signature(object = 'MAXENT_biomod2_model'),
           function(object, newdata, silent=TRUE, ...){
-            
             args <- list(...)
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.MAXENT_biomod2_model.RasterStack(object, newdata, silent=TRUE, ... ))
@@ -946,7 +1012,13 @@ setMethod('predict', signature(object = 'MAXENT_biomod2_model'),
                        " doclamp=false visible=false autorun nowarnings notooltips", sep=""), wait = TRUE, intern=TRUE)
   
   if(!silent) cat("\n\t\tReading Maxent outputs...")
-  proj <- raster(file.path(MWD$m_workdir,"projMaxent.asc"))
+  proj <- raster(file.path(MWD$m_workdir,"projMaxent.asc"), crs=projection(newdata), RAT=FALSE)
+  
+#   # keep the coordinates ref system of new data
+#   # TO DO => do it in .Prepare.Maxent.Proj.WorkDir()
+#   proj.ref <- projection(newdata)
+  
+  # 
   
   #   if(length(get_scaling_model(object))){
   #     names(proj) <- "pred"
@@ -954,16 +1026,23 @@ setMethod('predict', signature(object = 'MAXENT_biomod2_model'),
   #   }
 
   if(on_0_1000) proj <- round(proj*1000)
-  
+
   # save raster on hard drive ?
   if(!is.null(filename)){
-    if(!silent) cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    cat("\n\t\tWriting projection on hard drive...")
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   } else if(!inMemory(proj)){
     proj <- readAll(proj) # to prevent from tmp files removing
   }
   
+  
+  
+  
   if(!is.null(rm_tmp_files)){
     if(rm_tmp_files){
 #       unlink(x=file.path(object@resp_name, temp_workdir), recursive=TRUE, force=TRUE )
@@ -1071,13 +1150,15 @@ setClass('RF_biomod2_model',
 
 setMethod('predict', signature(object = 'RF_biomod2_model'),
           function(object, newdata, ...){
-            
             args <- list(...)
             
-#             if( ! ("package:randomForest" %in% search()) ){ require(randomForest,quietly=TRUE) }
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.RF_biomod2_model.RasterStack(object, newdata, ... ))
@@ -1108,8 +1189,12 @@ setMethod('predict', signature(object = 'RF_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
   return(proj)
@@ -1165,11 +1250,15 @@ setClass('SRE_biomod2_model',
 
 setMethod('predict', signature(object = 'SRE_biomod2_model'),
           function(object, newdata, ...){
-            
             args <- list(...)
             
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+            
             ## data checking
-            newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             if(inherits(newdata, 'Raster')){            
               return(.predict.SRE_biomod2_model.RasterStack(object, newdata, ... ))
@@ -1195,10 +1284,15 @@ setMethod('predict', signature(object = 'SRE_biomod2_model'),
   # save raster on hard drive ?
   if(!is.null(filename)){
     cat("\n\t\tWriting projection on hard drive...")
-    writeRaster(proj, filename=filename, overwrite=overwrite)
-    proj <- raster(filename)
+    if(on_0_1000){ ## projections are stored as positive integer 
+      writeRaster(proj, filename=filename, overwrite=overwrite, datatype="INT2S", NAflag="-9999")
+    } else { ## keep default data format for saved raster 
+      writeRaster(proj, filename=filename, overwrite=overwrite) 
+    }
+    proj <- raster(filename,RAT=FALSE)
   }
   
+  
   return(proj)
 }
 
@@ -1259,11 +1353,15 @@ setClass('EMmean_biomod2_model',
 
 setMethod('predict', signature(object = 'EMmean_biomod2_model'),
           function(object, newdata=NULL, formal_predictions=NULL, ...){
-            
             args <- list(...)
             
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+            
             ## data checking
-            if(length(newdata)) newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             ## check if models are formal loaded
             if(is.character(object@model)){
@@ -1328,8 +1426,13 @@ setMethod('predict', signature(object = 'EMmedian_biomod2_model'),
             
             args <- list(...)
             
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+            
             ## data checking
-            if(length(newdata)) newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             ## check if models are formal loaded
             if(is.character(object@model)){
@@ -1394,9 +1497,13 @@ setMethod('predict', signature(object = 'EMcv_biomod2_model'),
           function(object, newdata=NULL, formal_predictions=NULL, ...){
             
             args <- list(...)
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
             
             ## data checking
-            if(length(newdata)) newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             ## check if models are formal loaded
             if(is.character(object@model)){
@@ -1480,8 +1587,13 @@ setMethod('predict', signature(object = 'EMci_biomod2_model'),
             
             args <- list(...)
             
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+            
             ## data checking
-            if(length(newdata)) newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             ## check if models are formal loaded
             if(is.character(object@model)){
@@ -1583,8 +1695,13 @@ setMethod('predict', signature(object = 'EMca_biomod2_model'),
             
             args <- list(...)
             
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+            
             ## data checking
-            if(length(newdata)) newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             ## check if models are formal loaded
             if(is.character(object@model)){
@@ -1643,8 +1760,13 @@ setMethod('predict', signature(object = 'EMwmean_biomod2_model'),
             
             args <- list(...)
             
+            do_check <- args$do_check
+            if(is.null(do_check)) do_check <- TRUE
+            
             ## data checking
-            if(length(newdata)) newdata <- check_data_range(model=object, new_data=newdata)
+            if(do_check){
+              newdata <- check_data_range(model=object, new_data=newdata)
+            }
             
             ## check if models are formal loaded
             if(is.character(object@model)){
